import { CdkTasks, LambdaFunctionCommonOptions } from './awscdk';
import { CdkConfig, CdkConfigCommonOptions } from './awscdk/cdk-config';
import { TypeScriptAppProject, TypeScriptProjectOptions } from './typescript';
/**
 * @experimental
 */
export interface AwsCdkTypeScriptAppOptions extends TypeScriptProjectOptions, CdkConfigCommonOptions {
    /**
     * (experimental) AWS CDK version to use.
     *
     * @default "1.129.0"
     * @experimental
     * @featured true
     */
    readonly cdkVersion: string;
    /**
     * (experimental) Use pinned version instead of caret version for CDK.
     *
     * You can use this to prevent yarn to mix versions for your CDK dependencies and to prevent auto-updates.
     * If you use experimental features this will let you define the moment you include breaking changes.
     *
     * @default false
     * @experimental
     */
    readonly cdkVersionPinning?: boolean;
    /**
     * (experimental) Which AWS CDK modules (those that start with "@aws-cdk/") this app uses.
     *
     * @experimental
     * @featured true
     */
    readonly cdkDependencies?: string[];
    /**
     * (experimental) The CDK app's entrypoint (relative to the source directory, which is "src" by default).
     *
     * @default "main.ts"
     * @experimental
     */
    readonly appEntrypoint?: string;
    /**
     * (experimental) Automatically adds an `awscdk.LambdaFunction` for each `.lambda.ts` handler in your source tree. If this is disabled, you can manually add an `awscdk.AutoDiscover` component to your project.
     *
     * @default true
     * @experimental
     */
    readonly lambdaAutoDiscover?: boolean;
    /**
     * (experimental) Common options for all AWS Lambda functions.
     *
     * @default - default options
     * @experimental
     */
    readonly lambdaOptions?: LambdaFunctionCommonOptions;
}
/**
 * (experimental) AWS CDK app in TypeScript.
 *
 * @experimental
 * @pjid awscdk-app-ts
 */
export declare class AwsCdkTypeScriptApp extends TypeScriptAppProject {
    /**
     * (experimental) The CDK version this app is using.
     *
     * @experimental
     */
    readonly cdkVersion: string;
    /**
     * (experimental) The CDK app entrypoint.
     *
     * @experimental
     */
    readonly appEntrypoint: string;
    /**
     * (experimental) Common CDK tasks.
     *
     * @experimental
     */
    readonly cdkTasks: CdkTasks;
    /**
     * (experimental) cdk.json configuration.
     *
     * @experimental
     */
    readonly cdkConfig: CdkConfig;
    /**
     * @experimental
     */
    constructor(options: AwsCdkTypeScriptAppOptions);
    /**
     * (experimental) Adds an AWS CDK module dependencies.
     *
     * @param modules The list of modules to depend on.
     * @experimental
     */
    addCdkDependency(...modules: string[]): void;
    private formatModuleSpec;
}
